@@ -14,7 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2005, 2006, 2008 Brad Hards <bradh@frogmouth.net>
-// Copyright (C) 2005, 2007-2009, 2011-2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2007-2009, 2011-2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2008 Julien Rebetez <julienr@svn.gnome.org>
 // Copyright (C) 2008, 2010 Pino Toscano <pino@kde.org>
 // Copyright (C) 2008, 2010, 2011 Carlos Garcia Campos <carlosgc@gnome.org>
@@ -479,7 +479,7 @@ static PDFSubtypePart pdfPartFromString(PDFSubtype subtype, const std::string &p
 
 static PDFSubtypeConformance pdfConformanceFromString(const std::string &pdfsubver)
 {
-    const std::regex regex("PDF/(?:A|X|VT|E|UA)-[[:digit:]]([[:alpha:]]+)");
+    const std::regex regex("PDF/(?:A|X|VT|E|UA)-[[:digit:]]([[:alpha:]]{1,3})");
     std::smatch match;
 
     // match contains the PDF conformance (A, B, G, N, P, PG or U)
@@ -508,7 +508,7 @@ static PDFSubtypeConformance pdfConformanceFromString(const std::string &pdfsubv
             break;
         }
         case 2: {
-            if (conf == std::string_view("pq")) {
+            if (conf == std::string_view("pg")) {
                 return subtypeConfPG;
                 break;
             }
